@@ -66,7 +66,6 @@ File.getCadToolBarPanel = function() {
         action.setScriptFile(File.includeBasePath + "/File.js");
         action.objectName = actionName;
         action.setRequiresDocument(false);
-        action.setIcon(File.includeBasePath + "/File.svg");
         //action.setStatusTip(qsTr("Show file tools"));
         action.setNoState();
         action.setDefaultCommands(["filemenu"]);
@@ -203,7 +202,7 @@ File.getSaveFileName = function(parentWidget, caption, path, filterStrings, defa
         done = true;
 
         if (!fileDialog.exec()) {
-            fileDialog.destroy();
+            destrDialog(fileDialog);
             EAction.activateMainWindow();
             return undefined;
         }
@@ -230,7 +229,7 @@ File.getSaveFileName = function(parentWidget, caption, path, filterStrings, defa
         // file with suffix:
         fi = new QFileInfo(fileToSave);
         if (fi.exists()) {
-            var buttons = new QMessageBox.StandardButtons(QMessageBox.Yes, QMessageBox.No);
+            var buttons = makeQMessageBoxStandardButtons(QMessageBox.Yes, QMessageBox.No);
             var ret = QMessageBox.warning(parentWidget, 
                 qsTr("Overwrite File?"), 
                 qsTr("The file \"%1\" already exists. Do you wish to overwrite it?").arg(fileToSave),
@@ -273,14 +272,14 @@ File.getOpenFileName = function(parentWidget, caption, dir, filterStrings, noAll
     fileDialog.fileMode = QFileDialog.ExistingFiles;
     fileDialog.setLabelText(QFileDialog.FileType, qsTr("Format:"));
     if (!fileDialog.exec()) {
-        fileDialog.destroy();
+        destrDialog(fileDialog);
         EAction.activateMainWindow();
         return undefined;
     }
 
     var fileNames = fileDialog.selectedFiles();
     if (fileNames.length===0) {
-        fileDialog.destroy();
+        destrDialog(fileDialog);
         EAction.activateMainWindow();
         return undefined;
     }
@@ -292,7 +291,7 @@ File.getOpenFileName = function(parentWidget, caption, dir, filterStrings, noAll
 
     var nameFilter = fileDialog.selectedNameFilter();
 
-    fileDialog.destroy();
+    destrDialog(fileDialog);
     EAction.activateMainWindow();
 
     return [ fileNames[0], nameFilter ];
@@ -303,6 +302,11 @@ File.getOpenFileName = function(parentWidget, caption, dir, filterStrings, noAll
  * \param version String from the file version drop down in the save as dialog.
  */
 File.isRecommendedVersion = function(version) {
+    if (version.length>0 && !version.contains("*.dxf") && !version.contains("*.dwg") && !version.contains("*.aam")) {
+        // only dxf and dwg are recommended to save drawing files:
+        return false;
+    }
+
     if (version.indexOf("R2.5")!==-1) {
         return false;
     }
@@ -312,7 +316,7 @@ File.isRecommendedVersion = function(version) {
     else if (version.indexOf("R9")!==-1) {
         return false;
     }
-    else if (version.indexOf("R10")!==-1) {
+    else if (version.indexOf("R10")!==-1 && !version.contains("*.aam")) {
         return false;
     }
     else if (version.indexOf("R12")!==-1) {
